Module: QueueIt
- Extended by:
- QueueIt
- Included in:
- QueueIt
- Defined in:
- lib/queue_it.rb,
lib/queue_it/engine.rb,
lib/queue_it/version.rb,
app/models/queue_it/node.rb,
app/models/queue_it/queue.rb,
lib/queue_it/example_class.rb,
app/jobs/queue_it/application_job.rb,
app/models/queue_it/application_record.rb,
app/helpers/queue_it/application_helper.rb,
app/mailers/queue_it/application_mailer.rb,
app/controllers/queue_it/application_controller.rb
Defined Under Namespace
Modules: ApplicationHelper, Queable Classes: ApplicationController, ApplicationJob, ApplicationMailer, ApplicationRecord, Engine, ExampleClass, InstallGenerator, Node, Queue
Constant Summary collapse
- VERSION =
'0.2.0'
Instance Method Summary collapse
-
#setup {|_self| ... } ⇒ Object
You can add, in this module, your own configuration options as in the example below…
Instance Method Details
#setup {|_self| ... } ⇒ Object
You can add, in this module, your own configuration options as in the example below…
attr_writer :my_option
def my_option
return "Default Value" unless @my_option
@my_option
end
Then, you can customize the default behaviour (typically in a Rails initializer) like this:
QueueIt.setup do |config|
config.root_url = "Another value"
end
21 22 23 24 |
# File 'lib/queue_it.rb', line 21 def setup yield self require "queue_it" end |